All Classes and Interfaces
Class
Description
This class represents an ACL for a specific container instance.
This class maintains the iptables (ipv4 and ipv6) for all running containers.
A maintainer that is responsible for providing and refreshing Athenz credentials for a container.
Class to converge file/directory attributes like owner and permissions to wanted values.
The most basic form of a node repository report on a node.
Read and write interface to the CGroup of a podman container.
Read and write interface to the CGroup V1 of a Podman container.
Read and write interface to the CGroup V2 of a Podman container.
Base class for child process related exceptions, with a util to build an error message
that includes a large part of the output.
The child process terminated with a non-zero exit code.
A CommandLine is used to specify and execute a shell-like program in a child process,
and capture its output.
A CommandResult is the result of the execution of a CommandLine.
Interface to execute basic HTTP/HTTPS request against config server(s)
The result of sending a request to a config server results in a jackson response or exception.
Retries request on config server a few times before giving up.
The available (and implemented) APIs of the config server
Information necessary to e.g.
A Podman container.
The network of a container
Utility for manipulating the initial file system the Docker container will start with.
Interface for a container engine, such as Docker or Podman.
The ID of a container.
Download a container image asynchronously.
This class removes container images that have not been recently used by any containers.
Type-safe value wrapper for docker container names.
Container network modes supported by node-admin.
High-level interface for container operations.
Represents a path in container that is mapped in from the host.
CPU, GPU, memory and network statistics collected from a container.
Statistics for CPU usage
GPU statistics
Statistics for memory usage
Statistics for network usage
Wireguard task for containers.
Exception specially handled to avoid dumping full stack trace on convergence failure.
Takes in an uncompressed core dump and collects relevant metadata.
Finds coredumps, collects metadata and reports them
A maintainer that is responsible for providing and refreshing credentials for a container.
Simulates an editor cursor.
Cursor is a mutable offset into a fixed String, and useful for String parsing.
A start- and end- offset in an underlying String.
Class to make it easier to implement a NodeAdminDebugHandler:
- Forward to sub-NodeAdminDebugHandlers with addHandler,
- Specify constants with addConstant
- Forwarding to methods that dynamically build debug objects with addThreadSafeSupplier.
Rewrites default-env.txt files.
An editor meant to edit small line-based files like /etc/fstab.
This wrapper around PosixFileAttributes.
Deletes a file or empty directory.
Helper class to find and list or deleteRecursively files and directories.
Utility for idempotent move of (any type of) file.
A snapshot of the attributes of the file for a given path, and file content if it is a regular file.
Class to minimize resource usage with repetitive and mostly identical, idempotent, and
mutating file operations, e.g.
Write a file
Public methods common to both Template and ListElement.
This class represents a response from the /nodes/v2/acl/ API.
This class represents a response from the /nodes/v2/node/ API.
A response from the /nodes/v2/wireguard api.
Interface for verifying the health of the node.
The healthiness of a remote Vespa server based on REST API
Response from /state/v1/health
This class is thread unsafe: All method calls MUST be exclusive and serialized.
This represents a container image that exists locally.
Utils related to IOException.
IP addresses - IP utilities to retrieve and manipulate addresses for docker host and docker containers in a
multi-home environment.
Strong type IPv4 and IPv6 with common executables for ip related commands.
Exception thrown if the output of the child process is larger than the maximum limit.
Prioritizes files by first scoring them with the given scoring function and then mapping the scores to a
priority within the given range.
Class to ensure a directory exists with the correct owner, group, and permissions.
Represents a pattern match of a line
Stores the latest metric for the given application, name, dimension triplet in memory
NodeAdmin manages the life cycle of NodeAgents.
Interface for supporting debug info to introspect e.g.
Administers a host (for now only docker hosts) and its nodes (docker containers nodes).
Pulls information from node repository and forwards containers to run to node admin.
Responsible for management of a single node over its lifecycle.
For testing only!
This class should be used by exactly 2 threads, 1 for each interface it implements.
A node in the node repository is modified by setting which attributes to modify in this class,
and then patching the node repository node through
NodeRepository.updateNodeAttributes(String, NodeAttributes).API of node reports within node-admin.
All the states a node can be in the node-repository.
Abstraction for communicating with Orchestrator.
A partial container, containing only fields returned by a container list command such as 'podman ps'.
The state of a container
Represents a subset of a file's content, owner, group, and permissions.
Represents a position in the buffer
Process abstraction.
Represents /proc/meminfo, see proc(5).
Reads /proc/meminfo, see proc(5).
ConfigServerClients using the default implementation for the various clients,
and backed by a ConfigServerApi.Credentials for a container registry server.
Interface for retrieving credentials for a container registry.
Jackson class of JSON request, with names of fields verified in unit test.
The /state/v1 REST API of the config server
Class wrapping a boolean stored on disk.
Class wrapping a float stored on disk
Class wrapping an integer stored on disk
Edits multi-line text.
Control the systemd system and service manager
A
SystemCtl tester that simplifies testing interaction with systemd units.Uses the Velocity engine to render a template, to and from both String and Path objects.
The Java representation of a template text.
Specifies the how to interpret a template text.
A Terminal is a light-weight terminal-like interface for executing shell-like programs.
The location within an implied multi-line String.
Exception thrown when a child process has taken too long to terminate, in case it has been
forcibly killed.
Thin wrapper around java.nio.file.Path, especially nice for UNIX-specific features.
A regular UNIX-style user and its primary group.
Represents a snapshot of the TextBuffer, between two edits (or the initial or final state)
Encapsulates an IP address and its version along with some convenience methods.
Generates dumps for Vespa services and uploads resulting files to S3.
A wireguard peer.
A YUM/DNF package name.
A
Yum tester that simplifies testing interaction with yum.InputStream that outputs given InputStream compressed with the ZStandard.